## Description

Brief description of the changes.

## Type of change

- [ ] Bug fix
- [ ] New feature
- [ ] Documentation
- [ ] Refactoring
- [ ] Other (describe):

## Checklist

- [ ] Tests pass (`pytest`)
- [ ] Linting passes (`ruff check .`)
- [ ] Documentation updated (if applicable)
- [ ] Changes follow the "one parameter = one feature" philosophy

## Related issues

Fixes #
